# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject
# FileName:      read_ini.py
# Author:       liulei
# Datetime:     2024/7/13 20:19
# Description:
# 
# ---------------------------------------------------------------------------

import openpyxl

from APIAutoTest_V2_1.commen.read_ini import ReadIni
from APIAutoTest_V2_1.commen.read_json import ReadJson


class ReadExcel:
    def __init__(self):
        # 获取excel文件的路径和工作表
        self.RI = ReadIni()
        excel_path = self.RI.get_file("excel")
        table_name = self.RI.get_table("table")
        # 创建openpyxl对象
        wb = openpyxl.load_workbook(excel_path)
        self.ws = wb[table_name]

    def __get_value_cell(self, column, row):
        """配置一个对象内部使用的获取单元格值的方法"""
        Value = self.ws[column + str(row)].value
        if Value:
            if Value.strip():
                return Value.strip()
            else:
                return None
        else:
            return None

    def get_module_name(self, row):
        """获取模块名称"""
        try:
            module_name = self.__get_value_cell("B", row)
        except Exception as e:
            print("获取模块名称时出现错误，错误为：")
            raise e
        else:
            if module_name is None:
                return None
            else:
                return module_name

    def get_API_name(self, row):
        """获取接口名称"""
        try:
            API_name = self.__get_value_cell("C", row)
        except Exception as e:
            print("获取接口名称时出现错误，错误为：")
            raise e
        else:
            if API_name is None:
                return None
            else:
                return API_name

    def get_case_title(self, row):
        """获取用例标题"""
        try:
            case_title = self.__get_value_cell("D", row)
        except Exception as e:
            print("获取用例标题时出现错误，错误为：")
            raise e
        else:
            return case_title

    def get_request_method(self, row):
        """获取请求方法"""
        try:
            request_method = self.__get_value_cell("F", row)
        except Exception as e:
            print("获取请求方法时出现错误，错误为：")
            raise e
        else:
            return request_method

    def get_request_path(self, row):
        """获取请求路径"""
        try:
            path = self.__get_value_cell("G", row)
        except Exception as e:
            print("获取请求路径时出现错误，错误为：")
            raise e
        else:
            try:
                host = self.RI.get_url("test_host")
            except Exception as E:
                print("在获取请求路径时，读取被测系统域名时出现错误，错误为：")
                raise E
            else:
                if path is None:
                    return host
                else:
                    return host + path

    def get_mime(self, row):
        """获取媒体类型"""
        try:
            mime = self.__get_value_cell("H", row)
        except Exception as e:
            print("在获取媒体类型时出现错误，错误为：")
            raise e
        else:
            return mime

    def get_case_data(self, row):
        """获取用例数据"""
        try:
            case_data = self.__get_value_cell("I", row)
        except Exception as e:
            print("在excel中读取用例数据时出现错误，错误为：")
            raise e
        else:
                if self.get_module_name(row) is None or self.get_API_name(row) is None or case_data is None:
                    return None
                else:
                    try:
                        json_data = ReadJson("case")[self.get_module_name(row)][self.get_API_name(row)][case_data]
                    except KeyError as k:
                        print("读取该条json数据时出现错误，case_data为：", case_data)
                        print("获取json中的用例数据时，找不到对应的数据，错误为：")
                        raise k
                    else:
                        return json_data

    def get_expect_data(self, row):
        """获取期望数据"""
        try:
            expect_data = self.__get_value_cell("J", row)
        except Exception as e:
            print("在excel中读取期望数据时出现错误，错误为：")
            raise e
        else:
            try:
                if self.get_module_name(row) is None or self.get_API_name(row) is None:
                    return None
                else:
                    json_data = ReadJson("expect")[self.get_module_name(row)][self.get_API_name(row)][expect_data]
            except Exception as e:
                print("根据excel中的用例数据去读取json文件中的数据时出现错误，错误为：")
                raise e
            else:
                return json_data

    def get_sql_type(self, row):
        """根据key获取sql语句类型"""
        sql_type = self.__get_value_cell("K", row)
        if sql_type:
            print("读取excel中获取到的语句类型为：", sql_type)
            return sql_type

    def get_sql_data(self, row):
        """根据key读取sql语句"""
        sql_data_key = self.__get_value_cell("L", row)
        if sql_data_key:
            module_name = self.get_module_name(row)
            API_name = self.get_API_name(row)
            sql_data = ReadJson("sql")[module_name][API_name][sql_data_key]
            return sql_data

    def get_updatekey(self, row):
        """获取更新的key"""
        update_key = self.__get_value_cell("M", row)
        if update_key:
            return update_key

    def get_data_all(self):
        """将用例数据装进一个二维列表里面"""
        data_list = []
        try:
            for row in range(2, self.ws.max_row+1):
                list1 = [self.get_request_method(row), self.get_request_path(row), self.get_mime(row), self.get_case_data(row), self.get_expect_data(row), self.get_sql_type(row), self.get_sql_data(row), self.get_updatekey(row)]
                if self.get_module_name(row) is not None and self.get_API_name(row) is not None:
                    data_list.append(list1)
                else:
                    continue
        except Exception as e:
            print("获取所有用例数据时出现错误，错误为：")
            raise e
        else:
            return data_list

if __name__ == "__main__":
    RE = ReadExcel()

    list2 = RE.get_data_all()
    for i in range(len(list2)):
        print(i+1, end=' ')
        print(list2[i])
        print("="*140)
    #
    # s1 = "    "
    # print(s1.strip())
    # if s1.strip():
    #     print("hello")


