# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject
# FileName:      read_ini.py
# Author:       liulei
# Datetime:     2024/7/15 12:30
# Description:
# 
# ---------------------------------------------------------------------------

import openpyxl

from test_project.mine.APIAutoTest_V2_2.commen.read_ini import ReadIni
from test_project.mine.APIAutoTest_V2_2.commen.read_json import ReadJson


class ReadExcel:
    def __init__(self):
        # 获取excel文件路径和工作表名称
        self.ini = ReadIni()
        excel_path = self.ini.get_file("excel")
        table_name = self.ini.get_table("table")
        # 创建openpyxl对象
        wb = openpyxl.load_workbook(excel_path)
        self.ws = wb[table_name]

    def __get_cell_value(self, column, row):
        """封装一个私有方法，根据坐标获取单元格的值"""
        try:
            Value = self.ws[column + str(row)].value
            if Value:
                return Value.strip()
            else:
                return None
        except ValueError as v:
            print("获取excel表格中的值时出现错误：")
            raise v

    def get_module_name(self, row):
        """获取模块名称"""
        try:
            module_name = self.__get_cell_value("b", row)
        except:
            raise ValueError("获取模块名称时传入的row错误")
        else:
            return module_name

    def get_api_name(self, row):
        """获取接口名称"""
        try:
            api_name = self.__get_cell_value("c", row)
        except:
            raise ValueError("获取接口名称时传入的row错误")
        else:
            return api_name

    def get_case_title(self, row):
        """获取用例标题"""
        try:
            case_title = self.__get_cell_value("d", row)
        except:
            raise ValueError("获取用例标题时传入的row错误")
        else:
            return case_title

    def get_request_method(self, row):
        """获取请求方法"""
        try:
            request_method = self.__get_cell_value("f", row)
        except:
            raise ValueError("获取请求方法时传入的row错误")
        else:
            return request_method

    def get_request_path(self, row):
        """获取请求路径"""
        try:
            request_path = self.__get_cell_value("g", row)
        except:
            raise ValueError("获取请求路径时传入的row错误")
        else:
            if request_path:
                host = self.ini.get_host("test_host")
                return host + request_path

    def get_mime(self, row):
        """获取媒体类型"""
        try:
            mime = self.__get_cell_value("h", row)
        except:
            raise ValueError("获取媒体类型时传入的row错误")
        else:
            if mime:
                return mime.strip()


    def get_case_data(self, row):
        """获取用例数据"""
        try:
            case = self.__get_cell_value("i", row)
        except:
            raise ValueError("获取用例数据时传入的row错误")
        else:
            if case:
                case_data = ReadJson("case")[self.get_module_name(row)][self.get_api_name(row)][case]
                return case_data

    def get_expect_data(self, row):
        """获取期望数据"""
        try:
            expect = self.__get_cell_value("j", row)
        except:
            raise ValueError("获取期望数据时传入的row错误")
        else:
            if expect:
                expect_data = ReadJson("expect")[self.get_module_name(row)][self.get_api_name(row)][expect]
                return expect_data

    def get_sql_type(self, row):
        """获取sql语句类型"""
        try:
            sql_type = self.__get_cell_value("k", row)
        except:
            raise ValueError("获取sql语句类型时传入的row错误")
        else:
            return sql_type

    def get_sql_sentence(self, row):
        """获取sql语句"""
        try:
            sql_data = self.__get_cell_value("l", row)
        except:
            raise ValueError("获取sql语句时时传入的row错误")
        else:
            if sql_data:
                sql_sentence = ReadJson("sql")[self.get_module_name(row)][self.get_api_name(row)][sql_data]
                if sql_sentence:
                    return sql_sentence
            else:
                return None

    def get_update_key(self, row):
        """获取更新的key"""
        try:
            update_key = self.__get_cell_value("m", row)
        except:
            raise ValueError("获取更新的key时传入的row错误")
        else:
            return update_key

    def get_data_all(self):
        """将测试需要的数据封装进一个二维列表里面"""
        data_list = []
        for row in range(2, self.ws.max_row+1):
            module = self.get_module_name(row)
            api = self.get_api_name(row)
            title = self.get_case_title(row)
            req_method = self.get_request_method(row)
            req_path = self.get_request_path(row)
            req_mime = self.get_mime(row)
            case_data = self.get_case_data(row)
            expect = self.get_expect_data(row)
            sql_type = self.get_sql_type(row)
            sql_sentence = self.get_sql_sentence(row)
            update_key = self.get_update_key(row)
            list1 = [module, api, title, req_method, req_path, req_mime, case_data, expect, sql_type, sql_sentence, update_key]
            if module is not None and api is not None:
                data_list.append(list1)
        return data_list





if __name__ == "__main__":
    re = ReadExcel()
    print(re.get_data_all())
    # print(re.get_case_data(10))